@@ -15,7 +15,6 @@ from isc_common.bit import IsBitOn, TurnBitOn, TurnBitOff
 from isc_common.datetime import DateToStr
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.RPCResponse import RPCResponseConstant
-from isc_common.models.progresses import Progresses, ProgressesManager
 from isc_common.ws.webSocket import WebSocket
 from tracker.models.messages_state import Messages_state
 from tracker.models.messages_theme import Messages_theme
@@ -57,6 +56,8 @@ class LoginRequest(DSRequest):
                             self.response = dict(status=RPCResponseConstant.statusLoginIncorrect, errorMessage=f'Вход с логином "{login}" уже выполнен на {ip_address}')
                     else:
 
+                        from reports.models.jasper_reports_users import Jasper_reports_users
+                        from django.forms import model_to_dict
                         self.response = dict(
                             captionUser=user.get_short_name,
                             chatInfo=LoginRequest.get_chats(user),
@@ -87,6 +88,10 @@ class LoginRequest(DSRequest):
                             ws_channel=ws_channel,
                             ws_host=settings.WS_HOST,
                             ws_port=settings.WS_PORT,
+                            jasper_reports=[dict(
+                                report=model_to_dict(item.report),
+                                editor_identifier=item.editor_identifier,
+                            ) for item in Jasper_reports_users.objects.filter(user=user)]
                         )
                         request.session['ws_channel'] = ws_channel
                         request.session['ws_port'] = settings.WS_PORT
